resource "aws_cloudwatch_event_rule" "nta_pop_filter_glue_job_failure_rule" {
  name        = "${var.name_prefix}-failure-rule"
  description = "NTA pop filter glue job failure rule"
  tags        = var.tags
  event_pattern = jsonencode(
    {
      "detail-type" : ["Glue Job State Change"],
      "source" : ["aws.glue"],
      "detail" : {
        "jobName" : flatten(
          [for job in local.jobs :
            "${var.name_prefix}-${job}"
        ]),
        "state" : ["FAILED", "ERROR", "TIMEOUT", "STOPPED"]
      }
    }
  )
}

resource "aws_cloudwatch_event_target" "nta_pop_filter_glue_job_failure_sqs_target" {
  rule = aws_cloudwatch_event_rule.nta_pop_filter_glue_job_failure_rule.name
  arn  = var.job_dlq_arn
  input_transformer {
    input_paths = {
      "account"   = "$.account",
      "event"     = "$",
      "jobName"   = "$.detail.jobName",
      "jobRunId"  = "$.detail.jobRunId",
      "message"   = "$.detail.message",
      "region"    = "$.region",
      "status"    = "$.detail.state",
      "timestamp" = "$.time",
      "severity"  = "$.detail.severity"
    }

    input_template = <<TEMPLATE
  {
    "Message": "Glue job <jobName> state changed to <status> in account <account>, region <region> at <timestamp>.",
    "EventMessage": "<message>",
    "JobName": "<jobName>",
    "JobRunId": "<jobRunId>",
    "JobStatus": "<status>",
    "JobSeverity": "<severity>",
    "Timestamp": "<timestamp>"
  }
  TEMPLATE
  }

  dead_letter_config {
    arn = var.event_bridge_dlq_arn
  }
}
