########
# Provided by mcs2 magic
########

variable "tags" {
  type        = map(string)
  description = "Tags for all resources"
}

########
# User provided
########

#### These come from the config map and script magic

variable "processing_bucket_name" {
  type        = string
  description = "Name of the S3 bucket that has all of the jars, wheels, libs, in-flight and log data are located"
}

variable "data_bucket_name" {
  type        = string
  description = "Name of the S3 bucket that has all of the data"
}

variable "database_name" {
  type        = string
  description = "database name for nta-pop-filter data"
}

variable "job_dlq_arn" {
  type        = string
  description = "ARN of the SQS DLQ for failed jobs."
}

variable "event_bridge_dlq_arn" {
  type        = string
  description = "ARN of the SQS DLQ for event bridge. This is the DLQ for the job DLQ and is used if even bridge issues occur."
}

variable "name_prefix" {
  type        = string
  description = "Naming prefix to make mcs2 happy."
}

variable "iam_role_name" {
  type        = string
  description = "Name of the IAM role used by the Glue jobs."
}

variable "mcs2_env" {
  type        = string
  description = "Name of the mosaic 2 environment, e.g. kcdev01, prd5use1."
}

#### These come from the docker image

variable "default_nta_pop_lib_version" {
  type        = string
  description = "The default version of the library to use. This value is used unless one is provided by the config."
}

variable "bloom_filter_lib_version" {
  type        = string
  description = "The version of the bloom filter library to use."
}

#### These come from the helm chart

# Expected items:
#   * SRC_ACCOUNT_ID
#   * SRC_TABLE_NAME
#   * ENV_NAME: dev, stage, prod
#   * DEFAULT_NTA_POP_FILTER_LIB_VERSION
variable "extra_environment" {
  type        = map(string)
  description = "Environment variables coming from custom helm chart."
}

locals {
  jobs = ["netconn_target", "nta-pop-filter-31days"]
}
